Description: We should all do so well while under assault. ...
Keywords: jamie, dimon, says, banks, are, under, assault, as, he, announces, $4.9, billion, profit, business

View mobile site
January 14, 2015 Huffpost Business
Edition: U.S.

- Brasil BR
- Canada CA
- Deutschland DE
- España ES
- France FR
- Ελλάδα (Greece) GR
- India IN
- Italia IT
- 日本 (Japan) JP
- 한국 (Korea) KR
- Maghreb MG
- United Kingdom UK
- United States US

- Follow
- Newsletters
  Get BusinessNewsletters Email address Enter Email Address
- Huffington Post Search
  Search The Huffington Post Enter Search Terms Submit Search

- Here Is The Most Disproportionately Popular Cuisine In Each State 2015-01-14 07:35:12
- 'SORRY, NO CARNITAS' 2015-01-13 18:07:34
- 'Breastaurants' Thrive As The Restaurant Industry Struggles 2015-01-13 08:31:23
- Ralph Lauren's Native American Ads Reveal Sad Truth About The Fashion World 2015-01-13 11:25:37
- Here's One Way To Prove You're Working Hard At The Office 2015-01-12 09:47:26
- Here's A List Of All The Macy's Stores That Are Closing In 2015 2015-01-09 09:59:39
- Aetna CEO Asked Execs To Read Piketty, Then Gave His Lowest-Paid Workers A Raise 2015-01-13 09:28:31
- Cadbury Creme Eggs Aren't Changing In America, Everybody Relax 2015-01-12 15:23:17
- Oil Prices Actually Aren't That Low, Historically Speaking 2015-01-13 16:23:34
- Why Tesla Stock Is Plummeting Right Now 2015-01-14 13:20:13
- These J.C. Penney Stores Will Close In 2015 2015-01-08 10:50:07
- Why That Controversial McDonald's Ad Might Actually Work 2015-01-13 14:30:49
- Charlize Theron Proved You're Better Off When You Know Your Co-Workers' Pay 2015-01-12 11:07:57
- Why We're Picking Walmart And CVS Over Doctors' Offices 2015-01-12 14:31:18

Ben Walsh Become a fan benjamin.walsh@huffingtonpost.com

# Jamie Dimon Says Banks Are Under Assault As He Announces $4.9 Billion Profit

Posted: 01/14/2015 12:29 pm EST Updated: 01/14/2015 12:59 pm EST
Bloomberg via Getty Images

- Share
- Tweet
- 0
- Email
- Comment

- tumblr
- stumble
- reddit

We should all do so well while under assault.

JPMorgan Chase earned $4.9 billion in the fourth quarter of 2014, the company announced on Wednesday, down from a year ago, but capping what CEO Jamie Dimon called a record year for the biggest U.S. bank by assets.

Despite this success, Dimon warned that "banks are under assault," from government regulators.

"In the old days," Dimon said, "you dealt with one regulator when you had an issue, maybe two. “Now it’s five or six. It makes it very difficult and very complicated.

"You all should ask the question about how American that is. And how fair that is," he added. "And how complex that is for companies."

The biggest U.S. bank by assets has had its fair share of trouble with regulators in recent years. In the fourth quarter, JPMorgan paid $1.1 billion to settle charges by U.S. and foreign regulators that its traders had manipulated currency markets. In those settlements, J.P. Morgan did not admit nor deny any wrongdoing.

"Obviously, companies make mistakes," Dimon said on Wednesday. "We try to resolve it, we try to fix it, we admit it."

In the past two years, JPMorgan has paid out $14 billion in settlements and fines related to the London Whale trading losses, manipulating the key interest rate benchmark Libor, and issuing bad mortgages that helped lead to the financial crisis.

The bank earned $39.7 billion in net income over those same two years.

Despite his complaints, Wall Street lobbyists, and Dimon himself, are orchestrating a "continuing assault" on the 2010 Dodd-Frank financial-reform law that "has achieved remarkable success," as the New York Times put it on Tuesday.

Dimon personally lobbied for Congress to loosen derivatives rules put in place by Dodd-Frank financial. Late in December, the Federal Reserve gave banks another year to comply with certain aspects of that law's Volcker Rule, which prohibits proprietary trading. And now House Republicans are lining up a vote to extend that grace period until 2019, a full nine years after the bill was put into law.

If record profits and regulatory rollbacks are Dimon's idea of an assault on banks, it's hard to imagine what he thinks victory looks like.

### Around the Web

JPMORGAN CHASE & CO (JPM:New York): Earnings Estimates ...

JPMorgan Chase reports second-quarter 2014 earnings | J.P. Morgan

JPMorgan Misses Fourth Quarter Earnings Amid Fixed Income Trading Declines

Recap: JP Morgan's and Wells Fargo's Earnings

JPMORGAN CHASE & CO (JPM:New York): Earnings Estimates ...

What to watch for in JP Morgan earnings

Tesla, JP Morgan drop; GameStop jumps on solid sales

Click here to view Conversations

### Conversations

## Suggested For You

## FOLLOW HUFFPOST

- Email Address Please check the checkbox to indicate your consent
  Options
  The Morning Email
  Business

  Get top stories and blog posts emailed to me each day..

- - HuffPost
    Business
- - HuffPost
    Follow
    Business
    Follow
- - HuffPost
    Business
- - Most Popular on HuffPost
  - Latest News
  - Business
  - All RSS / Feeds
- - Available on the App Store
  - Android App on Google Play
  - Get it at Blackberry App World

#### Use this form to alert a HuffPost editor about a factual or typographical error in this story.

Notify message
* Required
* *
* What kind of error is this?
* What is the correction? 0 count
Describe the error here (1,000 character limit)

* Type the words below so we know you are not a cyborg

Sign me up for The Morning Email
Thanks for your report!